@@ -16,6 +16,7 @@ class CPPyKeen(EntityRelationEmbeddingModelPyKeen):
         batch_size: int = 2**10,
         training_loop: Union[str, Type[TrainingLoop]
                              ] = "Stochastic Local Closed World Assumption",
+        verbose: bool = False,
         random_state: int = 42,
         enable_cache: bool = False
     ):
@@ -46,6 +47,8 @@ class CPPyKeen(EntityRelationEmbeddingModelPyKeen):
             Can either be:
             - Stochastic Local Closed World Assumption
             - Local Closed World Assumption
+        verbose: bool = False
+            Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
         enable_cache: bool = False
@@ -58,17 +61,18 @@ class CPPyKeen(EntityRelationEmbeddingModelPyKeen):
             epochs=epochs,
             batch_size=batch_size,
             training_loop=training_loop,
+            verbose=verbose,
             random_state=random_state,
             enable_cache=enable_cache
         )
 
     def parameters(self) -> Dict[str, Any]:
-        return {
+        return dict(
             **super().parameters(),
             **dict(
                 rank=self._rank,
             )
-        }
+        )
 
     @classmethod
     def model_name(cls) -> str:
@@ -90,4 +94,5 @@ class CPPyKeen(EntityRelationEmbeddingModelPyKeen):
             triples_factory=triples_factory,
             embedding_dim=self._embedding_size,
             rank=self._rank,
+            random_seed=self._random_state
         )
