@@ -17,6 +17,7 @@ class PairREPyKeen(EntityRelationEmbeddingModelPyKeen):
         batch_size: int = 2**10,
         training_loop: Union[str, Type[TrainingLoop]
                              ] = "Stochastic Local Closed World Assumption",
+        verbose: bool = False,
         random_state: int = 42,
         enable_cache: bool = False
     ):
@@ -49,6 +50,8 @@ class PairREPyKeen(EntityRelationEmbeddingModelPyKeen):
             Can either be:
             - Stochastic Local Closed World Assumption
             - Local Closed World Assumption
+        verbose: bool = False
+            Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
         enable_cache: bool = False
@@ -62,18 +65,19 @@ class PairREPyKeen(EntityRelationEmbeddingModelPyKeen):
             epochs=epochs,
             batch_size=batch_size,
             training_loop=training_loop,
+            verbose=verbose,
             random_state=random_state,
             enable_cache=enable_cache
         )
 
     def parameters(self) -> Dict[str, Any]:
-        return {
+        return dict(
             **super().parameters(),
             **dict(
                 p=self._p,
                 power_norm=self._power_norm,
             )
-        }
+        )
 
     @classmethod
     def model_name(cls) -> str:
@@ -96,4 +100,5 @@ class PairREPyKeen(EntityRelationEmbeddingModelPyKeen):
             embedding_dim=self._embedding_size,
             p=self._p,
             power_norm=self._power_norm,
+            random_seed=self._random_state
         )
